@@ -15,7 +15,7 @@ WIDTH, HEIGHT = size()
 async def check_number(number: str) -> bool:
     """Checks if the Number is Valid or not"""
 
-    return "+" in number or "_" in number
+    return ("+" in number) or ("_" in number)
 
 
 async def close_tab(wait_time: int = 2) -> None:
